PageGenRequest class

Input for gen page <feature>/<name>.

Constructors

PageGenRequest({required String feature, required String name, bool form = true, int steps = 1, String? editModel})
const
PageGenRequest.parse(String path, {bool form = true, int steps = 1, String? editModel})
Parses debt/add → feature=debt, name=add.
factory

Properties

editModel String?
final
feature String
final
form bool
final
hashCode int
The hash code for this object.
no setterinherited
name String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
steps int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited